@@ -2,7 +2,7 @@ use 5.006;
 use warnings;
 
 package SQL::Interpol;
-$SQL::Interpol::VERSION = '1.101';
+$SQL::Interpol::VERSION = '1.102';
 # ABSTRACT: interpolate Perl variables into SQL statements
 
 use Exporter::Tidy all => [ qw( sql_interp sql ) ];
@@ -18,7 +18,7 @@ sub sql_interp {
 
 
 package SQL::Interpol::Parser;
-$SQL::Interpol::Parser::VERSION = '1.101';
+$SQL::Interpol::Parser::VERSION = '1.102';
 use Object::Tiny::Lvalue qw( alias_id bind );
 
 use Carp ();
@@ -162,7 +162,8 @@ sub bind_or_parse_values {
     } @_;
 }
 
-undef *VALID, *IDENT_RX;
+undef *VALID;
+undef *IDENT_RX;
 
 1;
 
@@ -178,7 +179,7 @@ SQL::Interpol - interpolate Perl variables into SQL statements
 
 =head1 VERSION
 
-version 1.101
+version 1.102
 
 =head1 SYNOPSIS
 
